==> viha-5.15.tar.gz: viha-5.15/hlo-takt-1.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "hlo";
$file = "hlo-takt-1.php";

include "common.php";
include "hlo-ok.php";

echo "
<html>
<head>
 <title>VIHA - Henkil</title>
</head>
" . body_bgcolor() . "
<h1>" . ota_paivystys_nimi() . ", henkilkohtaisten tietojen pivitys</h1>
";

taktiset_linkit();

function kutsut ($current_hlo_id, $current_kutsu_id)
{
  global $prefix;
  
  $sql1 =
    "SELECT id,kutsu
     FROM ryhma
     WHERE id != $current_kutsu_id 
           AND (alue_id = 2
                OR (alue_id = " . s("alue") . " AND paivystys_id = 2)
                OR (paivystys_id = " . s("paivystys") . "))
     ORDER BY pri";
  $result1 = my_mysql_query ($sql1);
  while ($b = mysql_fetch_array($result1)) {
    echo "<a href=\"$file?id=$current_hlo_id&ryhma_id=$b[id]\">$b[kutsu]</a> ";
  }
}

function hlo_tilat ($current_hlo_id, $current_hlo_tila_id)
{
  global $prefix;
  
  $sql1 =
    "SELECT id,hlo_tila
     FROM hlo_tila
     WHERE id != $current_hlo_tila_id
           AND (alue_id = 2
                OR (alue_id = " . s("alue") . " AND paivystys_id = 2)
                OR (paivystys_id = " . s("paivystys") . "))
     ORDER BY hlo_tila";
  $result1 = my_mysql_query ($sql1);
  while ($b = mysql_fetch_array($result1)) {
    echo "<a href=\"$file?id=$current_hlo_id&hlo_tila_id=$b[id]\">"
      . "$b[hlo_tila]</a> ";
  }
}

function hlo_asemat ($current_hlo_id, $current_hlo_asema_id)
{
  $sql1 = "
SELECT id,hlo_asema
FROM hlo_asema
WHERE id != $current_hlo_asema_id
ORDER BY pri
";
  $result1 = my_mysql_query ($sql1);
  while ($b = mysql_fetch_array($result1)) {
    echo "<a href=\"$file?id=$current_hlo_id&hlo_asema_id=$b[id]\">"
      . "$b[hlo_asema]</a> ";
  }
}

$id = get_nro('id');
$ryhma_id = get_nro('ryhma_id');
$hlo_tila_id = get_nro('hlo_tila_id');
$hlo_asema_id = get_nro('hlo_asema_id');

oltava_sallittu($file, $table, $id);

if (($ryhma_id != '') && saa_tehda("$file:ryhma_id")) {
  $ret = hlo_set_ryhma_id_ok($herja,$id,$ryhma_id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE hlo
       SET paivystys_id=" . s("paivystys") . ",
           ryhma_id=$ryhma_id,
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot pivitetty.\n";
    loki($sql);
    taktinen_loki(ota_nimi($id)
		  . " on nyt ryhmss "
		  . ota_kutsu($ryhma_id));
    add_hlo_ajat($id);
  }
  p_herja($ret,$herja);
 }

if (($hlo_tila_id != '') && saa_tehda("$file:hlo_tila_id")) {
  $ret = hlo_set_hlo_tila_id_ok($herja,$id,$hlo_tila_id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE hlo
       SET paivystys_id=" . s("paivystys") . ",
           hlo_tila_id=$hlo_tila_id,
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql,true,true);
    taktinen_loki(ota_nimi($id)
		  . " "
		  . ota_hlo_tila($hlo_tila_id));
    add_hlo_ajat($id);
    echo "<p>Tiedot pivitetty.\n";
  }
  p_herja($ret,$herja);
 }

if (($hlo_asema_id != '') && saa_tehda("$file:hlo_asema_id")) {
  $ret = hlo_set_hlo_asema_id_ok($herja,$id,$hlo_asema_id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE hlo
       SET paivystys_id=" . s("paivystys") . ",
           hlo_asema_id=$hlo_asema_id,
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot pivitetty.\n";
    loki($sql);
    taktinen_loki(ota_nimi($id)
		  . " "
		  . ota_hlo_asema($hlo_asema_id));
    add_hlo_ajat($id);
  }
  p_herja($ret,$herja);
 }

echo "<form action=\"\" method=\"GET\">\n";

$sql =
  "SELECT hlo.nimi,ryhma_id,hlo_tila_id,hlo_asema_id,kutsu,hlo_tila,hlo_asema,
          jarjesto
   FROM hlo,ryhma,hlo_tila,hlo_asema,jarjesto
   WHERE hlo.id = $id AND ryhma.id = hlo.ryhma_id
         AND hlo_tila.id = hlo.hlo_tila_id
         AND hlo_asema.id = hlo.hlo_asema_id
         AND jarjesto.id = hlo.jarjesto_id
         AND hlo.paivystys_id = " . s("paivystys");
$result = my_mysql_query($sql);
$a = mysql_fetch_array($result);
$nimi = $a['nimi']; $ryhma_id = $a['ryhma_id'];
$hlo_tila_id = $a['hlo_tila_id'];
$hlo_asema_id = $a['hlo_asema_id'];
$kutsu = $a['kutsu'];
$hlo_tila = $a['hlo_tila'];
$hlo_asema = $a['hlo_asema'];
$jarjesto = $a['jarjesto'];

echo "<table border=0>\n";
echo "<tr><td><td>Nimi:<td>$nimi\n";
echo "<tr><td><td>Jrjest:<td>$jarjesto\n";
echo tr_bgcolor() . "<th><th>Nykyinen<th>Pivitysvaihtoehdot";
echo "<tr><td>Ryhm:<td" . bgcolor_vaalsin() . ">$kutsu<td>";
kutsut ($id, $ryhma_id);
echo "<tr><td>Tila:<td" . bgcolor_vaalsin() . ">$hlo_tila<td>";
hlo_tilat ($id, $hlo_tila_id);
echo "<tr><td>Asema:<td" . bgcolor_vaalsin() . ">$hlo_asema<td>";
hlo_asemat ($id, $hlo_asema_id);

echo "</table>\n";

echo "<h2>Tulosteet</h2>";

echo "<p><a href=\"hlo-historia.php?id=$id\">",
  "Henkilkohtainen historia</a>\n";

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: hlo-takt-1.php,v 1.10 2009/05/09 05:58:07 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/hlo-takt-1.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "hlo";
$file = "hlo-takt-1.php";

include "common.php";
include "hlo-ok.php";

echo "
<html>
<head>
 <title>VIHA - Henkil</title>
</head>
" . body_bgcolor() . "
<h1>" . muotoile_operaatio() . ", henkilkohtaisten tietojen pivitys</h1>
";

taktiset_linkit();

function kutsut ($current_hlo_id, $current_kutsu_id)
{
  global $prefix;
  
  $sql1 =
    "SELECT id,kutsu
     FROM ryhma
     WHERE id != $current_kutsu_id 
           AND (alue_id = 2
                OR (alue_id = " . s("alue") . " AND paivystys_id = 2)
                OR (paivystys_id = " . s("paivystys") . "))
     ORDER BY pri";
  $result1 = my_mysql_query ($sql1);
  while ($b = mysql_fetch_array($result1)) {
    echo "<a href=\"$file?id=$current_hlo_id&ryhma_id=$b[id]\">$b[kutsu]</a> ";
  }
}

function hlo_tilat ($current_hlo_id, $current_hlo_tila_id)
{
  global $prefix;
  
  $sql1 =
    "SELECT id,hlo_tila
     FROM hlo_tila
     WHERE id != $current_hlo_tila_id
           AND (alue_id = 2
                OR (alue_id = " . s("alue") . " AND paivystys_id = 2)
                OR (paivystys_id = " . s("paivystys") . "))
     ORDER BY hlo_tila";
  $result1 = my_mysql_query ($sql1);
  while ($b = mysql_fetch_array($result1)) {
    echo "<a href=\"$file?id=$current_hlo_id&hlo_tila_id=$b[id]\">"
      . "$b[hlo_tila]</a> ";
  }
}

function hlo_asemat ($current_hlo_id, $current_hlo_asema_id)
{
  $sql1 = "
SELECT id,hlo_asema
FROM hlo_asema
WHERE id != $current_hlo_asema_id
ORDER BY pri
";
  $result1 = my_mysql_query ($sql1);
  while ($b = mysql_fetch_array($result1)) {
    echo "<a href=\"$file?id=$current_hlo_id&hlo_asema_id=$b[id]\">"
      . "$b[hlo_asema]</a> ";
  }
}

$id = get_nro('id');
$ryhma_id = get_nro('ryhma_id');
$hlo_tila_id = get_nro('hlo_tila_id');
$hlo_asema_id = get_nro('hlo_asema_id');

oltava_sallittu($file, $table, $id);

if (($ryhma_id != '') && saa_tehda("$file:ryhma_id")) {
  $ret = hlo_set_ryhma_id_ok($herja,$id,$ryhma_id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE hlo
       SET paivystys_id=" . s("paivystys") . ",
           ryhma_id=$ryhma_id,
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    loki($sql);
    $msg = ota_nimi($id) . " on nyt ryhmss " . ota_kutsu($ryhma_id);
    taktinen_loki($msg);
    tehty($msg);
    add_hlo_ajat($id);
  }
  p_herja($ret,$herja);
 }

if (($hlo_tila_id != '') && saa_tehda("$file:hlo_tila_id")) {
  $ret = hlo_set_hlo_tila_id_ok($herja,$id,$hlo_tila_id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE hlo
       SET paivystys_id=" . s("paivystys") . ",
           hlo_tila_id=$hlo_tila_id,
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql,true,true);
    $msg = ota_nimi($id) . " " . ota_hlo_tila($hlo_tila_id);
    taktinen_loki($msg);
    tehty($msg);
    add_hlo_ajat($id);
  }
  p_herja($ret,$herja);
 }

if (($hlo_asema_id != '') && saa_tehda("$file:hlo_asema_id")) {
  $ret = hlo_set_hlo_asema_id_ok($herja,$id,$hlo_asema_id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE hlo
       SET paivystys_id=" . s("paivystys") . ",
           hlo_asema_id=$hlo_asema_id,
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    loki($sql);
    $msg = ota_nimi($id) . " " . ota_hlo_asema($hlo_asema_id);
    taktinen_loki($msg);
    tehty($msg);
    add_hlo_ajat($id);
  }
  p_herja($ret,$herja);
 }

echo "<form action=\"\" method=\"GET\">\n";

$sql =
  "SELECT hlo.nimi,ryhma_id,hlo_tila_id,hlo_asema_id,kutsu,hlo_tila,hlo_asema,
          jarjesto
   FROM hlo,ryhma,hlo_tila,hlo_asema,jarjesto
   WHERE hlo.id = $id AND ryhma.id = hlo.ryhma_id
         AND hlo_tila.id = hlo.hlo_tila_id
         AND hlo_asema.id = hlo.hlo_asema_id
         AND jarjesto.id = hlo.jarjesto_id
         AND hlo.paivystys_id = " . s("paivystys");
$result = my_mysql_query($sql);
$a = mysql_fetch_array($result);
$nimi = $a['nimi']; $ryhma_id = $a['ryhma_id'];
$hlo_tila_id = $a['hlo_tila_id'];
$hlo_asema_id = $a['hlo_asema_id'];
$kutsu = $a['kutsu'];
$hlo_tila = $a['hlo_tila'];
$hlo_asema = $a['hlo_asema'];
$jarjesto = $a['jarjesto'];

echo "<table border=0>\n";
echo "<tr><td><td>Nimi:<td>$nimi\n";
echo "<tr><td><td>Jrjest:<td>$jarjesto\n";
echo tr_vaalsin() . "<th><th>Nykyinen<th>Pivitysvaihtoehdot";
echo "<tr><td>Ryhm:<td" . bgcolor_vaalsin() . ">$kutsu<td>";
kutsut ($id, $ryhma_id);
echo "<tr><td>Tila:<td" . bgcolor_vaalsin() . ">$hlo_tila<td>";
hlo_tilat ($id, $hlo_tila_id);
echo "<tr><td>Asema:<td" . bgcolor_vaalsin() . ">$hlo_asema<td>";
hlo_asemat ($id, $hlo_asema_id);

echo "</table>\n";

echo "<h2>Tulosteet</h2>";

echo "<p><a href=\"hlo-historia.php?id=$id\">",
  "Henkilkohtainen historia</a>\n";

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: hlo-takt-1.php,v 1.13 2009/10/04 16:31:17 riku Exp $ -->
